@@ -1,6 +1,5 @@
 /*
     SPDX-FileCopyrightText: 2013-2019 Andreas Cord-Landwehr <cordlandwehr@kde.org>
-
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
@@ -16,7 +15,7 @@ class TestCourseResource : public QObject
 public:
     TestCourseResource();
 
-private slots:
+private Q_SLOTS:
     /**
      * @brief Called before every test case.
      */
